model Rectifier "Rectifier that transforms and converts AC current to DC current."
  parameter Modelica.Units.SI.Voltage Vforward(displayUnit = "V") = 0.7 "Forward voltage drop of diodes";
  Modelica.Electrical.Analog.Ideal.IdealDiode diode1(Vknee = Vforward, Ron = 1.E-5) "Forward-biased diode to rectify current" annotation(Placement(visible = true, transformation(origin = {-10, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -313.788)));
  Modelica.Electrical.Analog.Ideal.IdealDiode diode3(Vknee = Vforward, Ron = 1.E-5) "Forward-biased diode to rectify current" annotation(Placement(visible = true, transformation(origin = {-10, -10}, extent = {{-10, -10}, {10, 10}}, rotation = -43.577)));
  Modelica.Electrical.Analog.Ideal.IdealDiode diode4(Vknee = Vforward, Ron = 1.E-5) "Forward-biased diode to rectify current" annotation(Placement(visible = true, transformation(origin = {10, -10}, extent = {{-10, -10}, {10, 10}}, rotation = -315)));
  Modelica.Electrical.Analog.Ideal.IdealDiode diode2(Vknee = Vforward, Ron = 1.E-5) "Forward-biased diode to rectify current" annotation(Placement(visible = true, transformation(origin = {10, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -45)));
  Modelica.Electrical.Analog.Basic.Resistor load(R = 1) "Resistive component to simulate a resistive load" annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Capacitor capacitor(C.displayUnit = "mF", C = 0.047, v.start = 0) "Smoothing capacitor" annotation(Placement(visible = true, transformation(origin = {120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Sources.SineVoltage source(V = 230, f = 60) "Mains electricity" annotation(Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Ideal.IdealTransformer transformer(Lm1 = 1, n = 24) "Transformer converting mains electricity to lower voltage" annotation(Placement(visible = true, transformation(origin = {-60, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Electrical.Analog.Basic.Ground ground "Mains neutral" annotation(Placement(visible = true, transformation(origin = {-100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Electrical.Analog.Basic.Ground ground1 "Mains neutral" annotation(Placement(visible = true, transformation(origin = {-40, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
equation
  connect(capacitor.n, load.n) annotation(Line(visible = true, origin = {100, -20}, points = {{20, 10}, {20, -10}, {-20, -10}, {-20, 10}}, color = {10, 90, 224}));
  connect(source.n, ground.p) annotation(Line(visible = true, origin = {-110, -20}, points = {{-10, 10}, {-10, 0}, {10, 0}, {10, -10}}, color = {10, 90, 224}));
  connect(diode2.p, transformer.p2) annotation(Line(visible = true, origin = {-15.414, 16.828}, points = {{18.343, 0.243}, {15.414, 0.243}, {15.414, 3.172}, {-24.586, 3.172}, {-24.586, -6.828}}, color = {10, 90, 224}));
  connect(transformer.n2, diode4.p) annotation(Line(visible = true, origin = {-18.512, -15.69}, points = {{-21.488, 5.69}, {-21.488, 5.69}, {-21.488, -4.31}, {18.512, -4.31}, {18.512, -1.381}, {21.441, -1.381}}, color = {10, 90, 224}));
  connect(transformer.n1, source.n) annotation(Line(visible = true, origin = {-104, -14}, points = {{24, -6}, {-16, -6}, {-16, 4}}, color = {10, 90, 224}));
  connect(source.p, transformer.p1) annotation(Line(visible = true, origin = {-104, 14}, points = {{-16, -4}, {-16, 6}, {24, 6}}, color = {10, 90, 224}));
  connect(diode3.p, load.n) annotation(Line(visible = true, origin = {10.918, -12.184}, points = {{-28.162, 9.077}, {-28.163, 12.184}, {-40.918, 12.184}, {-40.918, -17.816}, {69.082, -17.816}, {69.082, 2.184}}, color = {10, 90, 224}));
  connect(diode3.p, diode1.p) annotation(Line(visible = true, origin = {-17.202, -0.109}, points = {{-0.042, -2.998}, {-0.108, 0.109}, {0.282, 2.89}}, color = {10, 90, 224}));
  connect(diode2.n, load.p) annotation(Line(visible = true, origin = {45.69, 8.821}, points = {{-28.619, -5.892}, {-28.619, -8.821}, {-5.69, -8.821}, {-5.69, 11.179}, {34.31, 11.179}, {34.31, 1.179}}, color = {10, 90, 224}));
  connect(load.p, capacitor.p) annotation(Line(visible = true, origin = {100, 15}, points = {{-20, -5}, {-20, 5}, {20, 5}, {20, -5}}, color = {10, 90, 224}));
  connect(diode4.n, diode2.n) annotation(Line(visible = true, origin = {16.985, 0.008}, points = {{0.086, -2.937}, {0.118, -2.076}, {0.086, 2.921}}, color = {10, 90, 224}));
  connect(diode3.n, diode4.p) annotation(Line(visible = true, origin = {-0.861, -17.012}, points = {{-1.895, 0.119}, {-1.895, -0.059}, {3.79, -0.059}}, color = {10, 90, 224}));
  connect(diode1.n, diode2.p) annotation(Line(visible = true, origin = {-1.077, 17.12}, points = {{-2.003, 0.099}, {-2.003, -0.049}, {4.006, -0.049}}, color = {10, 90, 224}));
  connect(ground1.p, transformer.n2) annotation(Line(visible = true, origin = {-40, -20}, points = {{0, -10}, {0, 10}}, color = {10, 90, 224}));
  annotation(__Wolfram(openClass = "Rectifier", ControlPanels(Panel(identifier = "trusting-euclid", title = "Model parameter", elements = {InputField(variable = Vforward, label = "Forward voltage drop of diodes")}))), uses(Modelica(version = "4.0.0")), __Wolfram(PlotSet(plots = {Plot(name = "TransformerAndLoad", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = load.v, legend = "Load Voltage"), Curve(x = time, y = transformer.v2, legend = "Transformer Secondary Side Voltage")}), SubPlot(curves = {Curve(x = time, y = source.v)})}), Plot(name = "CapacitorCharging", subPlots = {SubPlot(curves = {Curve(x = time, y = der(capacitor.v), legend = "Capacitor Voltage Derivative")})}), Plot(name = "DiodeCurrentAndVoltage", subPlots = {SubPlot(curves = {Curve(x = time, y = diode1.i, legend = "Diode 1 & 4 Current"), Curve(x = time, y = diode2.i, legend = "Diode 2 & 3 Current")}), SubPlot(curves = {Curve(x = time, y = diode1.v, legend = "Diode 1 & 4 Voltage"), Curve(x = time, y = diode2.v, legend = "Diode 2 & 3 Voltage")}, range = Range(xmin = 0, xmax = 0.1, ymin = auto, ymax = auto))})})), experiment(StopTime = 0.1, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>
<p>This model studies the full-wave bridge rectifier. A rectifier is a circuit in which alternating current (AC), such as the one coming from ordinary household power sockets, is converted into direct current (DC). Direct current is needed for low-voltage appliances such as computer circuitry.</p>
</p>

<h4>Model Principles</h4>

<p>The model uses an AC input voltage of 230 V with a frequency of 60 Hz. Through the use of an <a href=\"modelica://Modelica.Electrical.Analog.Ideal.IdealTransformer\">ideal transformer</a>, the voltage is transformed down to around 9.5 V. The other end of the transformer is connected to four <a href=\"modelica://Modelica.Electrical.Analog.Ideal.IdealDiode\">diodes</a>. The diodes will only let current pass through in one direction, which is indicated by the arrow in the diode icon. Additionally, the voltage over the diode will also need to be higher than the diode forward voltage threshold. For silicon diodes, this voltage threshold is around 0.6 to 0.7 volts.</p>

<p>When the voltage source produces a positive potential on the positive pin, the current will pass through two of the diodes, one on the way into the load and one on the way back from the load. When the polarity of the voltage source is reversed, the two diodes that previously let current through in their forward direction will now block current in their backward direction, and the current will flow through the two remaining diodes. Regardless of polarity, the current will enter the load through the positive pin (filled, blue).</p>

<p>With only the transformer, the rectifier, and the load, the voltage over the load will alternate from zero to positive peak voltage. To reduce the ripple over the load, one or more <a href=\"modelica://Modelica.Electrical.Analog.Basic.Capacitor\">capacitors</a> are often added. The capacitor will oppose the change in voltage. It will store energy during the peak periods and release energy during the off periods. The capacitance of the capacitor needed depends on the amplitude of the AC voltage. For this low-voltage circuit (~10 V), a 47 mF capacitor is used.</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Rectifier/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<h4>Plot the Results</h4>

<p>Examine the automatically displayed stored plot and see how the alternating current gets converted to direct current. Explore how the voltage from the transformer (before rectification) compares to the voltage over the load (after rectification).</p>

<p>You can also compare the rectified voltage to the voltage before transformation. The source voltage is higher than the transformed voltage by a factor of 24.</p>

<p>You should now see the following graphs:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Rectifier/DocumentationFiles/plot.png\" style=\"width:600px\" alt=\"\" /></p>

<h4>Analysis</h4>

<p>Study the graphs produced in the Simulation section. Notice how the load voltage never reaches the transformer peak voltage. Regardless of voltage, it will always deviate 1.4 V from the peak. This is due to voltage drop caused by the silicon diodes.</p>

<p>You can verfy that this is the case by changing the forward voltage of the diodes. Do this by performing the following steps:</p>

<ul>
<li>Switch to the Parameter tab on the left in the Experiment Browser.</li>
<li>Scroll down to the Vforward parameter. This is the parameter that describes the minimum voltage needed to get current flowing in the diodes' forward direction.</li>
<li>Change the value of the Vforward parameter to 0 by typing 0 in the box next to the parameter.</li>
<li>Simulate by clicking the Simulate button or by pressing Ctrl+R.</li>
</ul>

<p>Now that 0 voltage is needed for the current to flow through in the forward direction, the peak voltage from the transformer should be equal to the peak voltage over the load.</p>

<p>You should now see the graph below:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Rectifier/DocumentationFiles/plot2.png\" style=\"width:600px\" alt=\"\" /></p>

</html>", figures = {Figure(title = "Transformer and load", identifier = "4bbf8", preferred = true, plots = {Plot(curves = {Curve(y = load.v, legend = "Load Voltage"), Curve(y = transformer.v2, legend = "Transformer Secondary Side Voltage")}), Plot(curves = {Curve(y = source.v)})}), Figure(title = "Capacitor charging", identifier = "b4c68", plots = {Plot(curves = {Curve(y = der(capacitor.v), legend = "Capacitor Voltage Derivative")})}), Figure(title = "Diode current and voltage", identifier = "bd603", plots = {Plot(curves = {Curve(y = diode1.i, legend = "Diode 1 & 4 Current"), Curve(y = diode2.i, legend = "Diode 2 & 3 Current")}), Plot(curves = {Curve(y = diode1.v, legend = "Diode 1 & 4 Voltage"), Curve(y = diode2.v, legend = "Diode 2 & 3 Voltage")}, x = Axis(min = 0, max = 0.1, unit = "s"))})}), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-135, -55}, {140, 35}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end Rectifier;
